---
title: "Slack guidelines"
linkTitle: "Slack guidelines"
weight: 45
type: "docs"
aliases:
  - /contributing/slack-guidelines/
---

Slack is the main communication platform for Knative outside of our mailing
lists. It’s important that conversation stays on topic in each channel, and that
everyone abides by the [Code of Conduct](./CODE-OF-CONDUCT.md). Community
members should all expect to have a positive experience.

Chat is searchable and public. Do not make comments that you would not say on a
video recording or in another public space. Please be courteous to others.

`@here` and `@channel` should be used rarely. Members will receive notifications
from these commands and we are a global project - please be kind. Note: `@all`
is only to be used by admins.

You can join the [CNCF Slack](https://communityinviter.com/apps/cloud-native/cncf) instance at
https://slack.cncf.io.

The Knative specific channels are:
* [#knative](https://cloud-native.slack.com/archives/C04LGHDR9K7)
* [#knative-client](https://cloud-native.slack.com/archives/C04LY4SKBQR)
* [#knative-conformance](https://cloud-native.slack.com/archives/C04LKFZ1UFL)
* [#knative-contributors](https://cloud-native.slack.com/archives/C04LN0620E8)
* [#knative-documentation](https://cloud-native.slack.com/archives/C04LY5G9ED7)
* [#knative-eventing](https://cloud-native.slack.com/archives/C04LMU33V1S)
* [#knative-functions](https://cloud-native.slack.com/archives/C04LKEZUXEE)
* [#knative-productivity](https://cloud-native.slack.com/archives/C04LY4M2G49)
* [#knative-release](https://cloud-native.slack.com/archives/C04LY4Y3EHF)
* [#knative-security](https://cloud-native.slack.com/archives/C04LGJ0D5FF)
* [#knative-serving](https://cloud-native.slack.com/archives/C04LMU0AX60)
* [#knative-toc-sc-questions](https://cloud-native.slack.com/archives/C04LQCW0C03)

## Code of Conduct

The Knative [Code of Conduct](./CODE-OF-CONDUCT.md) applies throughout the
project, and includes all communication mediums.

## Admins

Members of the
[Technical Oversight Committee (TOC)](TECH-OVERSIGHT-COMMITTEE.md) and
[Knative Steering Committee (KSC)](STEERING-COMMITTEE.md) are also the
administrators for the Knative Slack instance.

Slack admins should make sure to mention this in the “What I do” section of
their Slack profile, as well as for which time zone.

To connect: please reach out in the #slack-admins channel or DM (Direct Message)
a member of the [KSC](STEERING-COMMITTEE.md) or
[TOC](TECH-OVERSIGHT-COMMITTEE.md).

### Admin expectations and guidelines

- Adhere to Code of Conduct
- Take care of spam as soon as possible, which may mean taking action by making
  members inactive
- Moderating and fostering a safe environment for conversations
- Bring Code of Conduct issues to the Steering Committee
- Create relevant channels and list Code of Conduct in new channel welcome
  message
- Help troubleshoot Slack issues
- Review bot, token, and webhook requests
- Be helpful!

## Creating channels

Please reach out to the #slack-admins group with your request to create a new
channel.

Channels are dedicated to [Working Groups](./working-groups/WORKING-GROUPS.md),
sub-projects, community topics, and related programs/projects.

Channels are not:

- company specific; e.g. a channel named for a cloud provider must be used for
  conversation about Knative-related topics on that cloud, and not proprietary
  information of the provider.
- private unless there is an exception: code of conduct matters, mentoring,
  security/vulnerabilities, or steering committee.

All channels need a documented purpose. Use this space to welcome the targeted
community: promote your meetings, post agendas, etc.

We may make special accommodations where necessary.

## Escalating and/or reporting a problem

Join the #slack-admins channel or contact one of the admins in the closest
timezone via DM directly and describe the situation. If the issue can be
documented, please take a screenshot to include in your message.

### What if you have a problem with an admin

Send a DM to another listed Admin and describe the situation, or if it’s a code
of conduct issue, please send an email to
knative-code-of-conduct@googlegroups.com and describe the situation.

## Bots, tokens, and webhooks

Bots, tokens, and webhooks are reviewed on a case-by-case basis. Expect most
requests will be rejected due to security, privacy, and usability concerns. Bots
and the like tend to make a lot of noise in channels.

Please join #slack-admins and have a discussion about your request before
requesting the access.

## Admin moderation

Be mindful of how you handle communication during stressful interactions.
Administrators act as direct representatives of the project, and need to
maintain a very high level of professionalism at all times. If you feel too
involved in the situation to maintain impartiality or professionalism, that’s a
great time to enlist the help of another admin.

Try to take any situations that involve upset or angry members to DM or video
chat. Please document these interactions for other Slack admins to review.

Content will be automatically removed if it violates code of conduct or is a
sales pitch. Admins will take a screenshot of such behavior in order to document
the situation. Google takes such violations extremely seriously, and they will
be handled swiftly.

## Deactivating accounts

For reasons listed below, admins may deactivate individual Slack accounts. Due
to Slack’s framework, it does not allow for an account to be banned or suspended
in the traditional sense.
[Read Slack’s policy on this.](https://get.Slack.help/hc/en-us/articles/204475027-Deactivate-a-member-s-account)

- Spreading spam content in DMs or channels
- Not adhering to the [Code of Conduct](./CODE-OF-CONDUCT.md) in DMs or channels
- Overtly selling products, related or unrelated to Knative

## Specific channel rules

In the case that certain channels have rules or guidelines, they will be listed
in the purpose or pinned docs of that channel.

## Threaded Conversations

Slack threads in public channels are extremely useful for quickly and openly collaborating with your fellow contributors.  

Unfortunately, while Slack threads are good for quick discussion, they serve as a poor record of decisions. Discoverability and searchability of threads isn't nearly as good as alternatives (see below), particularly for contributors arriving weeks or months later. For this reason it's important that Slack discussions make their way to less ephemeral and more comprehensive artifacts for sharing ideas and proposals with the wider community.

These artifacts include, but are not limited to: Github Issues + Pull Requests, Github Discussions, Google Docs, or Mailing List posts.

As a general rule-of-thumb: if your Slack thread reaches more than 40 messages, ask yourself "If I weren't in this thread, would it be important for me to know the contents of this conversation?" If the answer is yes, it may be time to end the discussion and create one of the artifacts listed above to encourage slower and more deliberate discussion.

## DM (Direct Message) conversations

Please do not engage in proprietary company specific conversations in the
Knative Slack instance. This is meant for conversations related to Knative open
source topics and community.

Proprietary conversations should occur in your company communication platforms.
As with all communication, please be mindful of appropriateness,
professionalism, and applicability to the Knative community.

---

Except as otherwise noted, the content of this page is licensed under the
[Creative Commons Attribution 4.0 License](https://creativecommons.org/licenses/by/4.0/),
and code samples are licensed under the
[Apache 2.0 License](https://www.apache.org/licenses/LICENSE-2.0).
