---
title: "Knative technical oversight committee"
linkTitle: "Technical oversight committee"
weight: 35
type: "docs"
aliases:
  - /contributing/tech-oversight-committee/
---

The Knative Technical Oversight Committee (TOC) is responsible for cross-cutting
product and design decisions.

- [Charter](#charter)
- [Committee Mechanics](#committee-mechanics)
- [Committee Meeting](#committee-meeting)
- [Committee Members](#committee-members)

## Charter

- Technical Project Oversight, Direction & Delivery

  - Set the overall technical direction and roadmap of the project.

  - Resolve technical issues, technical disagreements and escalations within the
    project.

  - Set the priorities of individual releases to ensure coherency and proper
    sequencing.

  - Approve declaring a new long-term supported (LTS) Knative release.

  - Approve the creation and dissolution of working groups and approve
    leadership changes of working groups.

  - Create proposals based on TOC discussions and bring them to the relevant
    working groups for discussion.

  - Approve the creation/deletion of GitHub repositories, along with other
    high-level administrative issues around GitHub and our other tools.

- Happy Healthy Community

  - Establish and maintain the overall technical governance guidelines for the
    project.

  - Decide which sub-projects are part of the Knative project, including
    accepting new sub-projects and pruning existing sub-projects to maintain
    community focus

  - Ensure the team adheres to our
    [code of conduct](./CONTRIBUTING.md#code-of-conduct) and respects our
    [values](./VALUES.md).

  - Foster an environment for a healthy and happy community of developers and
    contributors.

## Committee Mechanics

The TOC is [elected by the community](./mechanics/TOC.md).

The TOC’s work includes:

- Regular committee meetings to discuss hot topics, resulting in a set of
  published
  [meeting notes](https://docs.google.com/document/d/1LzOUbTMkMEsCRfwjYm5TKZUWfyXpO589-r9K2rXlHfk/edit).

- Create, review, approve and publish technical project governance documents.

- Create proposals for consideration by individual working groups to help steer
  their work towards a common project-wide objective.

- Review/address/comment on project issues.

- Act as a high-level sounding board for technical questions or designs bubbled
  up by the working groups.

## Committee Meeting

Community members are encouraged to suggest topics for discussion ahead of the
TOC meetings, and are invited to observe these meetings and engage with the TOC
during the community feedback period at the end of each meeting.

| Artifact                   | Link                                                                                                                                                        |
| -------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Google Group               | [knative-tech-oversight@googlegroups.com](https://groups.google.com/forum/#!forum/knative-tech-oversight)                                                   |
| Community Meeting VC       | See the top of the [Meeting notes](https://docs.google.com/document/d/1LzOUbTMkMEsCRfwjYm5TKZUWfyXpO589-r9K2rXlHfk/edit)                                    |
| Community Meeting Calendar | Thursdays at 8:30a-9:15a <br>[Calendar](https://calendar.google.com/calendar/embed?src=knative.team_9q83bg07qs5b9rrslp5jor4l6s%40group.calendar.google.com) |
| Meeting Notes              | [Notes](https://docs.google.com/document/d/1LzOUbTMkMEsCRfwjYm5TKZUWfyXpO589-r9K2rXlHfk/edit)                                                               |
| Document Folder            | [Folder](https://drive.google.com/drive/folders/13-h81zualjRSNkCSFItODfk-NZ7dkMut)                                                                          |

## Committee Members

The current members of the TOC are shown below.

| &nbsp;                                                         | Member           | Company    | Profile                                              | Term Start | Term End |
| -------------------------------------------------------------- | ---------------- | ---------- | ---------------------------------------------------- | ---------- | --------
| <img width="30px" src="https://github.com/dprotaso.png">       | Dave Protasowski | VMware     | [@dprotaso](https://github.com/dprotaso)             | 2021-05-26 | 2024     |
| <img width="30px" src="https://github.com/dsimansk.png">       | David Simansky   | Red Hat    | [@dsimansk](https://github.com/dsimansk)             | 2022-06-01 | 2024     |
| <img width="30px" src="https://github.com/zroubalik.png">      | Zbynek Roubalik  | Red Hat    | [@zroubalik](https://github.com/zroubalik)           | 2022-06-01 | 2024     |
| <img width="30px" src="https://github.com/psschwei.png"> | Paul Schweigert | IBM | [@psschwei](https://github.com/psschwei) | 2022-09-28 | 2024 |
| <img width="30px" src="https://github.com/kvmware.png"> | Krsna Mahapatra | VMWare | [@kvmware](https://github.com/kvmware) | 2023-06-01 | 2025 |
## Emeritus Committee Members

To recognize the folks that have served in the TOC in the past, below we list the previous members of the TOC (sorted by their 'Term End').

| &nbsp;                                                         | Member          | Profile                                              | Term Start | Term End   |
| -------------------------------------------------------------- | ---------------  | --------------------------------------------------- | ---------- | ---------- |
| <img width="30px" src="https://github.com/vaikas.png">         | Ville Aikas     | [@vaikas](https://github.com/vaikas)                 | Bootstrap  | 2020       |
| <img width="30px" src="https://github.com/tcnghia.png">        | Nghia Tran      | [@tcnghia](https://github.com/tcnghia)               | 2020       | 2021       |
| <img width="30px" src="https://github.com/mattmoor.png">       | Matt Moore      | [@mattmoor](https://github.com/mattmoor)             | Bootstrap  | 2021       |
| <img width="30px" src="https://github.com/grantr.png">         | Grant Rodgers   | [@grantr](https://github.com/grantr)                 | 2020       | 2021       |
| <img width="30px" src="https://github.com/markusthoemmes.png"> | Markus Thömmes  | [@markusthoemmes](https://github.com/markusthoemmes) | 2020-06-09 | 2021-12-16 |
| <img width="30px" src="https://github.com/julz.png">           | Julian Friedman | [@julz](https://github.com/julz)                     | 2021-05-26 | 2022-02-07 |
| <img width="30px" src="https://github.com/rhuss.png">          | Roland Huß      | [@rhuss](https://github.com/rhuss)                   | 2021-02-16 | 2022       |
| <img width="30px" src="https://github.com/mattmoor.png">       | Matt Moore      | [@mattmoor](https://github.com/mattmoor)             | 2022-02-07 | 2022       |
| <img width="30px" src="https://github.com/n3wscott.png">       | Scott Nichols   | [@n3wscott](https://github.com/n3wscott)             | 2022-01-11 | 2022-09-27 |
| <img width="30px" src="https://github.com/evankanderson.png">  | Evan Anderson   | [@evankanderson](https://github.com/evankanderson)        | Bootstrap  | 2023-06-01 |

---

Except as otherwise noted, the content of this page is licensed under the
[Creative Commons Attribution 4.0 License](https://creativecommons.org/licenses/by/4.0/),
and code samples are licensed under the
[Apache 2.0 License](https://www.apache.org/licenses/LICENSE-2.0).
